#
# spec file for package python-pyOCD
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pyOCD
Version:        0.36.0
Release:        1.5
Summary:        CMSIS-DAP debugger for python
License:        Apache-2.0
URL:            https://github.com/mbedmicro/pyOCD
Source:         https://files.pythonhosted.org/packages/source/p/pyocd/pyocd-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-usb
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       python-pyocd = %{version}
Obsoletes:      python-pyocd < %{version}
BuildArch:      noarch
%python_subpackages

%description
On-chip debugger and flasher tool for ARM microcontrollers.

%prep
%setup -q -n pyocd-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyocd
%python_clone -a %{buildroot}%{_bindir}/pyocd-gdbserver
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative pyocd
%python_install_alternative pyocd-gdbserver

%postun
%python_uninstall_alternative pyocd
%python_uninstall_alternative pyocd-gdbserver

%files %{python_files}
%python_alternative %{_bindir}/pyocd
%python_alternative %{_bindir}/pyocd-gdbserver
%{python_sitelib}/pyocd
%{python_sitelib}/pyocd-%{version}.dist-info

%changelog
* Mon Nov 11 2024 Dirk Müller <dmueller@suse.com>
- update to 0.36.0:
  * Allow FlashBuilder to work when program page size is larger
    than sector erase size (@BrianPugh)
  * Very basic implementation to get a "connect" LED status
    display (@rgrr)
  * Add Trace Funnel Coresight component (@rapgenic)
  * Cortex-M CPU type detection improvements
  * Debug sequences: support pname on DebugPort* sequences
  * Add MAX32666FTHR board (@ozersa)
  * Add STMicro STM32 H743 and H723 targets (@unsanded)
  * nRF91 family improvements (@maxd-nordic)
  * Add HDSC HC32F448 hc32a460xe and hc32a4a0xi. (@lennvn)
  * Add airm2m air001 target (@kaidegit)
  * Add airm2m air32f103 target (@HalfSweet)
  * Add STMicro STM32H7B0 Target (@BrianPugh)
  * Add NXP S32K344 target (@PetervdPerk-NXP)
  * Add Realtek RTL8762C (@suphammer)
  * Add some missing ST and NXP board IDs
  * Fix HC32l130 32k+ flash error (@kaidegit)
  * Fix HC32L13x size and enable double buffering (@kaidegit)
  * Infineon PSoC6: remove unnecessary sleep during reset (@te-
    johan)
  * Remove part number match for NXP MIMXRTxxxx series family
  * RTT: fix CB not found (@tdasika)
  * CMSIS-DAP: Windows performance regression fix
  * Debug sequences: fix assignment expressions.
  * flash: fix some type errors, sort imports
  * Removed extraneous space character in the default `cortex_m`
    target warning message (@BenjaminSoelberg)
  * Flash loader: fix missing import of RamRegion
  * coresight: adiv5 discovery: increment invalid AP count on
    exception
  * cortex-m: reset_halt: just warn about invalid T-bit, don't
    automatically fix
  * commands: reset: fall back to reset via probe if context has
    no selected core
  * Only create one session to access options when there's no
    current session, to reduce debug log message output.
- update to 0.35.1:
  * debug sequences: support [uU] suffix on integer literals
  * commands: `show accessible-pins`: fix function call, print
    GPIO pins
  * commands: `show locked`: fix misspelled "target"
  * coresight: dap: revert API change to add DebugPort param to
    DPConnector constructor (in particular, this broke the NXP
    SPSDK tool's pyOCD support)
  * manifest: add sequences.lark
  * code quality: do not use bare exception handler
- update to 0.35.0:
  * With this release, Python 3.6 is no longer supported. The
    minimum Python version is now 3.7.0.
  * cmsis-packs: debug sequence support; see the documentation
    for details
  * rtt: add RTT support to gdbserver via the addition of an
    `rtt` command (thanks @samueldewan)
  * rtt: add logging function to rtt sub-command (thanks
    @zjli-2019)
  * coresight: cortex-m: 'primary_core' option
  * subcommands: Python tracebacks are no longer printed unless
    debug logging is enabled (the `debug.traceback` option is
    disabled by default)
  * object graph nodes have names now, accessible with the
    `.node_name` attribute
  * board and SoC nodes have default names of "board" and "soc"
  * CPUs will have a default (uniquified) name of the CPU type,
    or a custom name specified in a DFP
  * these names are visible in some of the commands such as `show
    cores` or `show graph`, and can be used in commands such as
    `core` (to select the core that commands apply to)
  * memory map: memory regions can have subregions; this is used
    for flash memory regions to explicitly support multiple
    sector sizes and/or flash algorithms
  * target: added generic `sw_system` and `sw_core` reset types
    (aliased as `system` and `core`, with
    `Target.ResetType.SW_SYSTEM` and `Target.ResetType.SW_CORE`
    enums in the API), corresponding to the existing
    `sysresetreq` and `vectreset` reset types
  * target: `.supported_reset_types` property returns a list of
    allowed reset type enums
  * flash: add `--no-reset` option to prevent resetting of device
    after programming (thanks @nordicjm)
  * flash: memory regions are now created when a DFP specifies an
    algorithm without also defining a corresponding memory
    region, as long as that algorithm is marked as default
  * core: `cache.enable_memory` and `cache.enable_register`
    session options to control the memory and register cache used
    by the gdb server
  * commands: add `show sequences` command
  * commands: add `reset-type` value to show and set current
    reset type and view available reset types
  * commands: new `sleep` command
  * commands: add `pins` and `accessible-pins` values
  * api: debug probe pins API
  * dependency: bump minimum cmsis-pack-manager version to 0.5.2
  * dependencies: bump pylink-square to minimum v1.0 (thanks
  * probe: accept WCH-Link as DAPv1 (thanks @eugene-bright)
  * probe: cmsis-dap: add "CMSIS_DAP" to known device strings
  * probe: stlink: cache board IDs to improve connect time
  * semihosting: ensure directories exist before opening a file
    (thanks @Hoohaha)
  * RTOS: Catch TransferErrors during kernel state checks (thanks
    @imi415)
  * flash: catch exceptions while fetching state (thanks @maxd-
    nordic)
  * coresight: discovery: continue after an AP probe failure
    occurs
  * core: soc_target: options to control memory and register
    cache enablement
  * trace: minor trace logging improvements
  * commands: reinit: set exec context attrs to defaults
* Thu Jul 27 2023 Steve Kowalik <steven.kowalik@suse.com>
- Switch to setuptools_scm, rather than setuptools_scm_git_archive.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.22.0:
  * Fixed regression with Cypress PSoC6 targets (#680) and merged in cumulative PSoC6 updates from Cypress.
  * Resolved a number of issues (but not all) with NXP LPC55S69.
  * Update ST NUCLEO-H743ZI.
  * Correct the wrong part number for MIMXRT1064-EVK board.
  * Correct part number for ST NUCLEO-WB55RG board.
  * Fix location of input data for flash algorithms in STM32F412xx target.
  * Address an issue with the built-in target STM32L031x6 by disabling double buffered flash programming.
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.21.0:
  * Too many changes to enumerate
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Apr  1 2018 afaerber@suse.de
- Convert to singlespec
- Update to v0.8.1a1
* Wed Jan  7 2015 afaerber@suse.de
- Drop py2pack-generated conditional on suse_version (matejcik)
* Tue Jan  6 2015 afaerber@suse.de
- Add runtime dependency on pyUSB
* Tue Jan  6 2015 afaerber@suse.de
- Initial: v0.2
